@@ -1,4 +1,4 @@
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 import sys
 
@@ -25,3 +25,7 @@ else:
 
 from pprp.utility import \
     trim_pkcs7_padding
+
+from pprp.source import \
+    file_source_gen, \
+    data_source_gen
